getEstimatedOdometryFix {#yarp_3_4}
--------------------------------

# Bugfix

### Devices

* Implemented missing method `getEstimatedOdometry()` in `localization2DClient`, `navigation2DClient`
* Implemented RPC in `localization2DServer`.

### Harness_dev

* Added test for `getEstimatedOdometry()` method in harness_dev (`Navigation2DClientTest.cpp`)
